use strict;
use warnings;


package FpcMgr;
use Qt;
use Qt::isa qw (Qt::Object);
use Qt::attributes qw (title_combo audio_combo subtitle_combo
		       title_list_items menu_table_items ct);
use QVamps qw (search);
use MenuTableItems;


sub NEW
{
  my $this             = shift;
  my $parent           = shift;
  my $name             = shift;
  my $title_combo      = shift;
  my $audio_combo      = shift;
  my $subtitle_combo   = shift;
  my $title_list_items = shift;
  my $menu_table_items = shift;

  $this -> SUPER::NEW ($parent, $name);

  title_combo      = $title_combo;
  audio_combo      = $audio_combo;
  subtitle_combo   = $subtitle_combo;
  title_list_items = $title_list_items;
  menu_table_items = $menu_table_items;
}


sub DESTROY
{
  parent () -> removeChild (this);

  ct               = 0;
  menu_table_items = undef;
  title_list_items = undef;
  subtitle_combo   = undef;
  audio_combo      = undef;
  title_combo      = undef;

  SUPER -> DESTROY ();
}


sub update_title
{
  my $nttn            = -1;
  my $title_combo     = title_combo;
  my $ttn             = $title_combo -> currentText ();
  my $selected_titles = title_list_items -> selected_titles ();

  # wipe out all combo box items
  $title_combo -> clear ();
  ct = 0;

  if (@{$selected_titles})
  {
    # list of selected titles not empty
    # --> create combo box items and set new title number to first in list
    $title_combo -> insertStringList ($selected_titles);
    $nttn = $title_combo -> currentText ();
    ct    = $nttn;

    if ($ttn)
    {
      # we had a title selected --> search in titles selected now
      my $i = search ($selected_titles, $ttn);

      unless ($i < 0)
      {
	# title still selected --> restore combo box selection
	$title_combo -> setCurrentItem ($i);
	ct = $ttn;

	# no need to update audio and subtitle combo boxes
	$nttn = 0;
      }
    }
  }

  # adjust width of combo box
  adjust_combo_width ($title_combo);

  return $nttn;
}


sub update_audio
{
  my $ttn = shift;

  my $audio_combo = audio_combo;

  $audio_combo -> clear ();

  unless ($ttn < 0)
  {
    my $item_hash = menu_table_items -> make_audio_item_hash ($ttn);
    my @streams   = sort { $a <=> $b } keys %{$item_hash};
    my @item_list = map $item_hash -> {$_}, @streams;
    my $i         = search (\@streams,
			    menu_table_items -> default_audio_stream ());

    $audio_combo -> insertStringList (\@item_list);
    $audio_combo -> setCurrentItem ($i) unless ($i < 0);
  }

  adjust_combo_width ($audio_combo);
}


sub update_subtitle
{
  my $ttn = shift;

  my $subtitle_combo = subtitle_combo;

  $subtitle_combo -> clear ();

  unless ($ttn < 0)
  {
    my $item_hash = menu_table_items -> make_subtitle_item_hash ($ttn);
    my @streams   = sort { $a <=> $b } keys %{$item_hash};
    my @item_list = map $item_hash -> {$_}, @streams;

    $subtitle_combo -> insertStringList (\@item_list);
  }

  adjust_combo_width ($subtitle_combo);
}


sub adjust_combo_width
{
  my $combo = shift;

  $combo -> setFont ($combo -> font ());
  $combo -> updateGeometry ();
}


sub update
{
  my $ttn = update_title ();

  if ($ttn)
  {
    update_audio ($ttn);
    update_subtitle ($ttn);
  }
}


sub title_changed
{
  my $ttn = shift;

  unless ($ttn == ct)
  {
    ct = $ttn;
    update_audio ($ttn);
    update_subtitle ($ttn);
  }
}


sub title_nr
{
  my $title_combo = title_combo;

  return 0 unless ($title_combo -> count ());

  return $title_combo -> currentItem () + 1;
}


sub audio_stream
{
  return audio_combo -> currentItem ();
}


sub subtitle_stream
{
  return audio_combo -> currentItem () - 1;
}


1;
